---
title: Quick Start
hide:
    - footer
---

# Quick Start Guides

`django-simple-deploy` aims to make deployment simple, so we offer a quick-start guide for each platform that's currently supported.
